Struct backroll::command::Commands[][src]

pub struct Commands<T> where
    T: Config
{ /* fields omitted */ }
An ordered container of commands for clients to execute.

Proper execution of the command is not optional, and must be done in the exact order they are returned in. Filtering or altering the order in which commands are executed, or dropping commands without executing them may result incorrect simulation and/or panics.