pub struct LoadState<T> where
T: Config, { /* fields omitted */ }
A command for loading a saved state of the game.
Loads the saved state of the game.
This will clone the internal copy ofthe save state. For games with
potentially large save state, this might be expensive.
Note this consumes the LoadState, loading multiple times is
not allowed.
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,